# swallow

- minimum hardware for [UGV control](https://github.com/kamangir/bluer-ugv/blob/main/bluer_ugv/docs/swallow/digital/design/computer).
- Raspberry Pi, 5 MP camera, 2+2 ultrasonic sensors, 2 x 12 VDC 43A DC motor drivers.
- width x height x length: 140 mm x 95 mm x 130 mm
- [parts](./parts.md)
- [body](./body/)
- [terraform](https://github.com/kamangir/bluer-ugv/blob/main/bluer_ugv/docs/swallow/digital/design/terraform.md).

|   |
| --- |
| [![image](https://github.com/kamangir/assets2/blob/main/swallow/design/v6/01.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/swallow/design/v6/01.jpg?raw=true) |
